@@ -1,14 +1,14 @@
 package Search::Elasticsearch;
 
-use Moo 1.003;
+use Moo 1.003 ();
 
 use Search::Elasticsearch::Util qw(parse_params load_plugin);
 use namespace::clean;
 
-our $VERSION = '1.19';
+our $VERSION = '1.20';
 
 my %Default_Plugins = (
-    client      => [ 'Search::Elasticsearch::Client',       'Direct' ],
+    client      => [ 'Search::Elasticsearch::Client',       '1_0::Direct' ],
     cxn_factory => [ 'Search::Elasticsearch::Cxn::Factory', '' ],
     cxn_pool    => [ 'Search::Elasticsearch::CxnPool',      'Static' ],
     logger      => [ 'Search::Elasticsearch::Logger',       'LogAny' ],
@@ -31,6 +31,7 @@ sub new {
     my ( $class, $params ) = parse_params(@_);
 
     $params->{cxn} ||= 'HTTPTiny';
+    my $plugins = delete $params->{plugins} || [];
 
     for my $name (@Load_Order) {
         my ( $base, $default ) = @{ $Default_Plugins{$name} };
@@ -38,6 +39,13 @@ sub new {
         my $plugin_class = load_plugin( $base, $sub_class );
         $params->{$name} = $plugin_class->new($params);
     }
+
+    for my $name (@$plugins) {
+        my $plugin_class
+            = load_plugin( 'Search::Elasticsearch::Plugin', $name );
+        $plugin_class->_init_plugin($params);
+    }
+
     return $params->{client};
 }
 
@@ -53,7 +61,7 @@ Search::Elasticsearch - The official client for Elasticsearch
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 SYNOPSIS
 
@@ -128,7 +136,7 @@ L<Search::Elasticsearch> is the official Perl client for Elasticsearch,
 supported by L<elasticsearch.com|http://www.elasticsearch.com>.  Elasticsearch
 itself is a flexible and powerful open source, distributed real-time
 search and analytics engine for the cloud.  You can read more about it
-on L<elasticsearch.org|http://www.elasticsearch.org>.
+on L<elastic.co|http://www.elastic.co>.
 
 =head1 BACKWARDS COMPATIBILITY AND ELASTICSEARCH 0.90.x
 
@@ -155,7 +163,7 @@ Unfortunately, the opinions of programmers seldom coincide. The intention of
 this client, and of the officially supported clients available for other
 languages, is to provide robust support for the full native Elasticsearch API
 with as few opinions as possible:  you should be able to read the
-L<Elasticsearch reference documentation|http://www.elasticsearch.org/guide>
+L<Elasticsearch reference documentation|http://www.elastic.co/guide>
 and understand how to use this client, or any of the other official clients.
 
 Should you decide that you want to customize the API, then this client
@@ -210,14 +218,14 @@ Easy extensibility
 =head1 INSTALLING ELASTICSEARCH
 
 You can download the latest version of Elasticsearch from
-L<http://www.elasticsearch.org/download>. See the
-L<installation instructions|http://www.elasticsearch.org/guide/reference/setup/installation/>
+L<http://www.elastic.co/download>. See the
+L<installation instructions|http://www.elastic.co/guide/reference/setup/installation/>
 for details. You will need to have a recent version of Java installed,
 preferably the Java v7 from Sun.
 
 =head1 CREATING A NEW INSTANCE
 
-The L</new()> method returns a new L<client|Search::Elasticsearch::Client::Direct>
+The L</new()> method returns a new L<client|Search::Elasticsearch::Client::1_0::Direct>
 which can be used to run requests against the Elasticsearch cluster.
 
     use Search::Elasticsearch;
@@ -337,7 +345,7 @@ Other arguments are explained in the respective L<module docs|/MODULES>.
 =head1 RUNNING REQUESTS
 
 When you create a new instance of Search::Elasticsearch, it returns a
-L<client|Search::Elasticsearch::Client::Direct> object, which can be used for
+L<client|Search::Elasticsearch::Client::1_0::Direct> object, which can be used for
 running requests.
 
     use Search::Elasticsearch;
@@ -358,7 +366,7 @@ running requests.
         }
     );
 
-See L<Search::Elasticsearch::Client::Direct> for more details about the requests that
+See L<Search::Elasticsearch::Client::1_0::Direct> for more details about the requests that
 can be run.
 
 =head1 MODULES
@@ -389,11 +397,21 @@ The class to use for the client functionality, which provides
 methods that can be called to execute requests, such as
 C<search()>, C<index()> or C<delete()>. The client parses the user's
 requests and passes them to the L</transport> class to be executed.
+
+The default version of the client is C<1_0::Direct>, which can
+be explicitly specified as follows:
+
+    $e = Search::Elasticsearch->new(
+        client => '1_0::Direct'
+    );
+
 See :
 
 =over
 
-=item * L<Search::Elasticsearch::Client::Direct> (default, for 1.0 branch)
+=item * L<Search::Elasticsearch::Client::1_0::Direct> (default, for 1.0 branch)
+
+=item * L<Search::Elasticsearch::Client::2_0::Direct> (for 2.0 branch)
 
 =item * L<Search::Elasticsearch::Client::0_90::Direct> (for 0.90 branch)
 
@@ -611,7 +629,7 @@ C<irc.freenode.net>.
 
 =item * Mailing list
 
-The main L<Elasticsearch mailing list|http://www.elasticsearch.org/community/forum/>.
+The main L<Elasticsearch mailing list|http://www.elastic.co/community>.
 
 =back
 
