@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Client::0_90::Direct::Indices;
-$Search::Elasticsearch::Client::0_90::Direct::Indices::VERSION = '1.19';
+$Search::Elasticsearch::Client::0_90::Direct::Indices::VERSION = '1.20';
 use Moo;
 with 'Search::Elasticsearch::Role::API::0_90';
 with 'Search::Elasticsearch::Role::Client::Direct';
@@ -17,7 +17,7 @@ Search::Elasticsearch::Client::0_90::Direct::Indices - A client for running inde
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 DESCRIPTION
 
@@ -48,7 +48,7 @@ Query string parameters:
     C<master_timeout>,
     C<timeout>
 
-See the L<create index docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-create-index.html>
+See the L<create index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-create-index.html>
 for more information.
 
 =head2 C<exists()>
@@ -60,7 +60,7 @@ for more information.
 The C<exists()> method returns C<1> or the empty string to indicate
 whether the specified index or indices exist.
 
-See the L<index exists docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-indices-exists.html>
+See the L<index exists docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-indices-exists.html>
 for more information.
 
 =head2 C<delete()>
@@ -75,7 +75,7 @@ Query string parameters:
     C<master_timeout>,
     C<timeout>
 
-See the L<delete index docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-delete-index.html>
+See the L<delete index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-delete-index.html>
 for more information.
 
 =head2 C<close()>
@@ -91,7 +91,7 @@ Query string parameters:
     C<master_timeout>,
     C<timeout>
 
-See the L<close index docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-open-close.html>
+See the L<close index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-open-close.html>
 for more information.
 
 =head2 C<open()>
@@ -106,7 +106,7 @@ Query string parameters:
     C<master_timeout>,
     C<timeout>
 
-See the L<open index docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-open-close.html>
+See the L<open index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-open-close.html>
 for more information.
 
 =head2 C<clear_cache()>
@@ -132,7 +132,7 @@ Query string parameters:
     C<index>,
     C<recycler>
 
-See the L<clear_cache docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-clearcache.html>
+See the L<clear_cache docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-clearcache.html>
 for more information.
 
 =head2 C<refresh()>
@@ -151,7 +151,7 @@ Query string parameters:
     C<ignore_indices>,
     C<ignore_unavailable>
 
-See the L<refresh index docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-refresh.html>
+See the L<refresh index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-refresh.html>
 for more information.
 
 =head2 C<flush()>
@@ -173,7 +173,7 @@ Query string parameters:
     C<ignore_unavailable>,
     C<refresh>
 
-See the L<flush index docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-flush.html>
+See the L<flush index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-flush.html>
 for more information.
 
 =head2 C<optimize()>
@@ -197,7 +197,7 @@ Query string parameters:
     C<refresh>,
     C<wait_for_merge>
 
-See the L<optimize index docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-optimize.html>
+See the L<optimize index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-optimize.html>
 for more information.
 
 =head2 C<snapshot_index()>
@@ -208,7 +208,7 @@ for more information.
 
 Deprecated.
 
-See the L<snapshot_index docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/>
+See the L<snapshot_index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/>
 for more information.
 
 =head1 MAPPING METHODS
@@ -246,7 +246,7 @@ Query string parameters:
     C<master_timeout>,
     C<timeout>
 
-See the L<put_mapping docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-put-mapping.html>
+See the L<put_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-put-mapping.html>
 for more information.
 
 =head2 C<get_mapping()>
@@ -259,7 +259,7 @@ for more information.
 The C<get_mapping()> method returns the type definitions for one, more or
 all types in one, more or all indices.
 
-See the L<get_mapping docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-get-mapping.html>
+See the L<get_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-get-mapping.html>
 for more information.
 
 =head2 C<get_field_mapping()>
@@ -275,7 +275,7 @@ for more information.
 The C<get_field_mapping()> method returns the field definitions for one, more or
 all fields in one, more or all types and indices.
 
-See the L<get_mapping docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-get-field-mapping.html>
+See the L<get_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-get-field-mapping.html>
 for more information.
 
 =head2 C<exists_type()>
@@ -294,7 +294,7 @@ Query string parameters:
     C<ignore_indices>,
     C<ignore_unavailable>
 
-See the L<exists_type docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-types-exists.html>
+See the L<exists_type docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-types-exists.html>
 for more information.
 
 =head2 C<delete_mapping()>
@@ -310,7 +310,7 @@ that type) in all specified indices.
 Query string parameters:
     C<master_timeout>
 
-See the L<delete_mapping docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-delete-mapping.html>
+See the L<delete_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-delete-mapping.html>
 for more information.
 
 =head1 ALIAS METHODS
@@ -337,7 +337,7 @@ Query string parameters:
     C<master_timeout>,
     C<timeout>
 
-See the L<update_aliases docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-aliases.html>
+See the L<update_aliases docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-aliases.html>
 for more information.
 
 =head2 C<get_aliases()>
@@ -354,7 +354,7 @@ the specified indices.
 Query string parameters:
     C<timeout>
 
-See the L<get_aliases docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-aliases.html>
+See the L<get_aliases docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-aliases.html>
 for more information.
 
 =head2 C<put_alias()>
@@ -380,7 +380,7 @@ Query string parameters:
     C<master_timeout>,
     C<timeout>
 
-See the L<put_alias docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-aliases.html>
+See the L<put_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-aliases.html>
 for more information.
 
 =head2 C<get_alias()>
@@ -399,7 +399,7 @@ Query string parameters:
     C<ignore_indices>,
     C<ignore_unavailable>
 
-See the L<get_alias docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-aliases.html>
+See the L<get_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-aliases.html>
 for more information.
 
 =head2 C<exists_alias()>
@@ -418,7 +418,7 @@ Query string parameters:
     C<ignore_indices>,
     C<ignore_unavailable>
 
-See the L<exists_alias docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-aliases.html>
+See the L<exists_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-aliases.html>
 for more information.
 
 =head2 C<delete_alias()>
@@ -434,7 +434,7 @@ Query string parameters:
     C<master_timeout>,
     C<timeout>
 
-See the L<delete_alias docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-aliases.html>
+See the L<delete_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-aliases.html>
 for more information.
 
 =head1 SETTINGS METHODS
@@ -459,7 +459,7 @@ indices or all indices. For instance:
 Query string parameters:
     C<master_timeout>
 
-See the L<put_settings docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-update-settings.html>
+See the L<put_settings docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-update-settings.html>
 for more information.
 
 =head2 C<get_settings()>
@@ -471,7 +471,7 @@ for more information.
 The C<get_settings()> method retrieves the index settings for the specified
 indices or all indices.
 
-See the L<get_settings docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-get-settings.html>
+See the L<get_settings docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-get-settings.html>
 for more information.
 
 =head1 TEMPLATE METHODS
@@ -490,7 +490,7 @@ Query string parameters:
     C<order>,
     C<timeout>
 
-See the L<put_template docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-templates.html>
+See the L<put_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-templates.html>
 for more information.
 
 =head2 C<get_template()>
@@ -501,7 +501,7 @@ for more information.
 
 The C<get_template()> method is used to retrieve a named template.
 
-See the L<get_template docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-templates.html>
+See the L<get_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-templates.html>
 for more information.
 
 =head2 C<delete_template()>
@@ -516,7 +516,7 @@ Query string parameters:
     C<master_timeout>,
     C<timeout>
 
-See the L<delete_template docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-templates.html>
+See the L<delete_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-templates.html>
 for more information.
 
 =head1 WARMER METHODS
@@ -545,7 +545,7 @@ to user searches.  For instance:
 Query string parameters:
     C<master_timeout>
 
-See the L<put_warmer docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-warmers.html>
+See the L<put_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-warmers.html>
 for more information.
 
 =head2 C<get_warmer()>
@@ -557,7 +557,7 @@ for more information.
 
 The C<get_warmer()> method is used to retrieve warmers by name.
 
-See the L<get_warmer docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-warmers.html>
+See the L<get_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-warmers.html>
 for more information.
 
 =head2 C<delete_warmer()>
@@ -572,7 +572,7 @@ The C<delete_warmer()> method is used to delete warmers by name.
 Query string parameters:
     C<master_timeout>
 
-See the L<delete_warmer docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-warmers.html>
+See the L<delete_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-warmers.html>
 for more information.
 
 =head1 STATS METHODS
@@ -612,7 +612,7 @@ Query string parameters:
     C<store>,
     C<warmer>
 
-See the L<stats docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-stats.html>
+See the L<stats docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-stats.html>
 for more information.
 
 =head2 C<status()>
@@ -631,7 +631,7 @@ Query string parameters:
     C<recovery>,
     C<snapshot>
 
-See the L<status docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-status.html>
+See the L<status docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-status.html>
 for more information.
 
 =head2 C<segments()>
@@ -649,7 +649,7 @@ Query string parameters:
     C<ignore_indices>,
     C<ignore_unavailable>
 
-See the L<segments docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-segments.html>
+See the L<segments docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-segments.html>
 for more information.
 
 =head1 QUERY AND ANALYSIS METHODS
@@ -676,7 +676,7 @@ Query string parameters:
     C<text>,
     C<tokenizer>
 
-See the L<analyze docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-analyze.html>
+See the L<analyze docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-analyze.html>
 for more information.
 
 =head2 C<validate_query()>
@@ -699,7 +699,7 @@ Query string parameters:
     C<q>,
     C<source>
 
-See the L<validate_query docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-validate.html>
+See the L<validate_query docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-validate.html>
 for more information.
 
 =head1 AUTHOR
