@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Role::Bulk;
-$Search::Elasticsearch::Role::Bulk::VERSION = '1.19';
+$Search::Elasticsearch::Role::Bulk::VERSION = '1.20';
 use Moo::Role;
 requires 'add_action', 'flush';
 
@@ -104,6 +104,12 @@ sub delete_ids {
     $self->add_action( map { ( 'delete' => { _id => $_ } ) } @_ );
 }
 
+our @Update_Params = qw(
+    doc upsert doc_as_upsert scripted_upsert
+    script script_id script_file
+    params lang detect_noop
+);
+
 #===================================
 sub _encode_action {
 #===================================
@@ -136,7 +142,7 @@ sub _encode_action {
 
     my $source;
     if ( $action eq 'update' ) {
-        for (qw(doc upsert doc_as_upsert script params lang)) {
+        for (@Update_Params) {
             $source->{$_} = delete $params->{$_}
                 if exists $params->{$_};
         }
@@ -255,7 +261,7 @@ Search::Elasticsearch::Role::Bulk - Provides common functionality to L<Elasticse
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 AUTHOR
 
