@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Role::Client::Direct;
-$Search::Elasticsearch::Role::Client::Direct::VERSION = '1.19';
+$Search::Elasticsearch::Role::Client::Direct::VERSION = '1.20';
 use Moo::Role;
 with 'Search::Elasticsearch::Role::Client';
 use Search::Elasticsearch::Util::API::Path qw(path_handler);
@@ -30,7 +30,7 @@ sub parse_request {
         my $name = $defn->{name} || '<unknown method>';
         $self->logger->throw_error( 'Param',
                   "$_ in ($name) request. "
-                . "See docs at: http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/"
+                . "See docs at: http://www.elastic.co/guide/en/elasticsearch/reference/current/"
                 . $defn->{doc}
                 . '.html' );
     };
@@ -120,7 +120,7 @@ Search::Elasticsearch::Role::Client::Direct - Request parsing for Direct clients
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 DESCRIPTION
 
