@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Role::Cxn::HTTP;
-$Search::Elasticsearch::Role::Cxn::HTTP::VERSION = '1.19';
+$Search::Elasticsearch::Role::Cxn::HTTP::VERSION = '1.20';
 use Moo::Role;
 
 use URI();
@@ -167,7 +167,7 @@ Search::Elasticsearch::Role::Cxn::HTTP - Provides common functionality to HTTP C
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 DESCRIPTION
 
@@ -252,7 +252,7 @@ unless you specify a custom C<max_content_length>:
 
 This client can request compressed responses from Elasticsearch by
 enabling the C<http.compression> config setting in
-L<Elasticsearch|http://www.elasticsearch.org/guide/reference/modules/http/>
+L<Elasticsearch|http://www.elastic.co/guide/reference/modules/http/>
 and setting C<deflate> to C<true>:
 
     $e = Search::Elasticsearch->new(
