@@ -1,5 +1,5 @@
 package Search::Elasticsearch::TestServer;
-$Search::Elasticsearch::TestServer::VERSION = '1.19';
+$Search::Elasticsearch::TestServer::VERSION = '1.20';
 use Moo;
 use Search::Elasticsearch();
 use POSIX 'setsid';
@@ -174,7 +174,7 @@ Search::Elasticsearch::TestServer - A helper class to launch Elasticsearch nodes
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 SYNOPSIS
 
@@ -205,7 +205,7 @@ be shutdown automatically.
         instances => 1,
         http_port => 9600,
         es_port   => 9700,
-        conf      => ['node.bench=true','script.disable_dynamic=false'],
+        conf      => ['script.disable_dynamic=false'],
     );
 
 Params:
