@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Transport;
-$Search::Elasticsearch::Transport::VERSION = '1.19';
+$Search::Elasticsearch::Transport::VERSION = '1.20';
 use Moo;
 
 use URI();
@@ -48,7 +48,6 @@ sub perform_request {
         }
 
         $logger->trace_error( $cxn, $error );
-        delete $error->{vars}{body};
         $error->is('NoNodes')
             ? $logger->throw_critical($error)
             : $logger->throw_error($error);
@@ -73,7 +72,7 @@ Search::Elasticsearch::Transport - Provides interface between the client class a
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 DESCRIPTION
 
@@ -92,7 +91,7 @@ L<Search::Elasticsearch::Role::Is_Sync>.
         send_get_body_as => 'POST'
     );
 
-Certain endpoints like L<Search::Elasticsearch::Client::Direct/search()>
+Certain endpoints like L<Search::Elasticsearch::Client::1_0::Direct/search()>
 default to using a C<GET> method, even when they include a request body.
 Some proxy servers do not support C<GET> requests with a body.  To work
 around this, the C<send_get_body_as>  parameter accepts the following:
